class pythonmsg:
    def __init__(self):
        self.text=["Good Luck"]
    def kprint(self):
        return "KAMARAJ COLLEGE OF ENGINEERING AND TECHNOLOGY        An Autonomous Institution           "
    def intern(self):
        return "Interning is done for performance optimization"
       

